@@ -185,35 +185,56 @@ class ModelTableField(CallableTableField):
 
     def valid(self):
         if isinstance(self.field, six.string_types):
-            field = self.view.model
-            for subfield in self.field.split("__"):
-                item = None
 
-                if isinstance(field, ModelBase):
-                    item = field._meta.get_field(subfield)
+            method_attr = getattr(self.view, self.field, None)
+            if method_attr:
+                print('view field', self.view, self.field)
+                if method_attr:
+                    field = property(method_attr)
+                else:
+                    field = method_attr
+            else:
+                field = self.view.model
+                for subfield in self.field.split("__"):
+                    item = None
 
-                    if getattr(item, 'related_model', None):
-                        item = item.related_model
-
-                    else:
+                    if isinstance(field, ModelBase):
                         try:
-                            if hasattr(item, 'get_queryset'):
-                                item = item.get_queryset().model
-                        except (Exception, FieldDoesNotExist):
+                            item = field._meta.get_field(subfield)
+
+                            if getattr(item, 'related_model', None):
+                                item = item.related_model
+
+                            if not item:
+                                try:
+                                    if hasattr(item, 'get_queryset'):
+                                        item = item.get_queryset().model
+                                except (Exception):
+                                    pass
+
+                            if not item:
+                                try:
+                                    # if its a field, then get it's verbose name
+                                    item = field._meta.get_field(subfield).verbose_name
+                                    self.is_model_field = True
+                                except (AttributeError):
+                                    pass
+                        except (FieldDoesNotExist):
                             pass
 
+                        # model attr
                         if not item:
-                            try:
-                                # if its a field, then get it's verbose name
-                                item = field._meta.get_field(subfield).verbose_name
-                                self.is_model_field = True
-                            except (AttributeError, FieldDoesNotExist):
-                                pass
+                            model_attr = getattr(item, subfield, None)
+                            if model_attr:
+                                if callable(model_attr):
+                                    item = property(model_attr)
+                                else:
+                                    item = model_attr
 
-                field = item
+                    field = item
 
-                if not field:
-                    break
+                    if not field:
+                        break
 
             self.attr = field
 
